==> pt_dev_utils-1.0.0.tar.gz: pt_dev_utils-1.0.0/pt_dev_utility/pt_time.py <==
# Compatible with Python 2.7 and Python 3.x
from __future__ import print_function, division, absolute_import

"""Time utility functions for date and timestamp operations.

This module provides cross-compatible functions for handling dates,
timestamps, and time calculations that work on both Python 2.7 and 3.x.
"""

from datetime import datetime, timedelta
from dateutil.relativedelta import relativedelta

try:
    from datetime import timezone
except ImportError:
    # Python 2.7 compatibility - minimal timezone implementation
    class timezone(object):
        """Simple timezone class for Python 2.7 compatibility."""
        
        def __init__(self, offset):
            # type: (timedelta) -> None
            """Initialize timezone with UTC offset.
            
            Args:
                offset: UTC offset as timedelta object.
            """
            self.offset = offset
        
        def utcoffset(self, dt):
            # type: (datetime) -> timedelta
            """Return UTC offset for given datetime."""
            return self.offset
        
        def tzname(self, dt):
            # type: (datetime) -> None
            """Return timezone name (always None for this implementation)."""
            return None
        
        def dst(self, dt):
            # type: (datetime) -> timedelta
            """Return daylight saving time offset (always zero)."""
            return timedelta(0)


def _get_datetime_components(mode):
    # type: (str) -> str or list # type: ignore
    """Get datetime components based on specified mode.
    
    Args:
        mode: Either 'current' for date components or 'time' for timestamp.
        
    Returns:
        List of date components ['year', 'month', 'day'] if mode='current',
        or formatted timestamp string if mode='time'.
    """
    current_date = datetime.now()
    
    if mode == 'current':
        # Return date components as list
        date_string = current_date.strftime('%Y_%m_%d')
        return date_string.split('_')
    elif mode == 'time':
        # Return formatted timestamp
        return current_date.strftime('%Y-%m-%d %H:%M:%S')
    else:
        raise ValueError("Mode must be 'current' or 'time'")


def get_current_date_components():
    # type: () -> dict
    """Get current date components as dictionary.
    
    Returns:
        Dictionary containing 'day', 'month', and 'year' as strings.
        
    Example:
        {'day': '15', 'month': '03', 'year': '2024'}
    """
    date_components = _get_datetime_components('current')
    year, month, day = date_components
    
    return {
        'day': day,
        'month': month,
        'year': year
    }


def get_current_timestamp():
    # type: () -> str
    """Get current timestamp as formatted string.
    
    Returns:
        Current timestamp in 'YYYY-MM-DD HH:MM:SS' format.
        
    Example:
        '2024-03-15 14:30:25'
    """
    return str(_get_datetime_components('time'))


def get_month_year_string(months_delta=0):
    # type: (int) -> str
    """Get month-year string with optional offset.
    
    Args:
        months_delta: Number of months to subtract from current date.
                     Positive values go back in time.
                     
    Returns:
        Month-year string in 'YYYY_MM' format.
        
    Example:
        get_month_year_string(0)  # '2024_03'
        get_month_year_string(1)  # '2024_02' (one month ago)
    """
    current_date = datetime.now()
    # Subtract the specified number of months
    target_date = current_date - relativedelta(months=months_delta)
    formatted_date = target_date.strftime("%Y_%m")
    
    return str(formatted_date)


def get_iso_timestamp_ist():
    # type: () -> str
    """Get current timestamp in ISO format with IST timezone.
    
    Returns:
        Current timestamp as ISO formatted string with IST offset (+05:30).
        
    Example:
        '2024-03-15T14:30:25+05:30'
        
    Note:
        Uses timezone-aware datetime in Python 3.x and falls back to
        manual offset calculation in Python 2.7.
    """
    # IST is UTC+5:30
    ist_offset = timezone(timedelta(hours=5, minutes=30))
    
    try:
        # Python 3.x - use timezone-aware datetime
        current_dt = datetime.now(ist_offset).replace(microsecond=0)
        return current_dt.isoformat()
    except TypeError:
        # Python 2.7 fallback - manual timezone offset
        current_dt = datetime.now() + timedelta(hours=5, minutes=30)
        current_dt = current_dt.replace(microsecond=0)
        return current_dt.strftime('%Y-%m-%dT%H:%M:%S+05:30')


# Legacy function aliases for backward compatibility
calculate = _get_datetime_components  # Deprecated: use specific functions
get_current_month_year = get_current_date_components  # Deprecated
get_timestamp = get_current_timestamp  # Deprecated
get_month_year = get_month_year_string  # Deprecated
get_iso_timestamp = get_iso_timestamp_ist  # Deprecated

==> pt_dev_utils-1.1.8.tar.gz: pt_dev_utils-1.1.8/pt_dev_utility/pt_time.py <==
"""Time utility functions for date and timestamp operations.

This module provides functions for handling dates, timestamps, and time
calculations for Python 3.8+.
"""

from datetime import datetime, timedelta, timezone
from typing import Dict, List, Union

from dateutil.relativedelta import relativedelta


def _get_datetime_components(mode: str) -> Union[List[str], str]:
    """Get datetime components based on specified mode.

    Args:
        mode: Either 'current' for date components or 'time' for timestamp.

    Returns:
        List of date components ['year', 'month', 'day'] if mode='current',
        or formatted timestamp string if mode='time'.
    """
    current_date = datetime.now()
    
    if mode == 'current':
        # Return date components as list
        date_string = current_date.strftime('%Y_%m_%d')
        return date_string.split('_')
    elif mode == 'time':
        # Return formatted timestamp
        return current_date.strftime('%Y-%m-%d %H:%M:%S')
    else:
        raise ValueError("Mode must be 'current' or 'time'")


def get_current_date_components() -> Dict[str, str]:
    """Get current date components as dictionary.

    Returns:
        Dictionary containing 'day', 'month', and 'year' as strings.

    Example:
        >>> get_current_date_components()
        {'day': '15', 'month': '03', 'year': '2024'}
    """
    date_components = _get_datetime_components('current')
    if isinstance(date_components, list):
        year, month, day = date_components
        return {
            'day': day,
            'month': month,
            'year': year
        }
    raise ValueError("Unexpected return type from _get_datetime_components")


def get_current_timestamp() -> str:
    """Get current timestamp as formatted string.

    Returns:
        Current timestamp in 'YYYY-MM-DD HH:MM:SS' format.

    Example:
        >>> get_current_timestamp()
        '2024-03-15 14:30:25'
    """
    return str(_get_datetime_components('time'))


def get_month_year_string(months_delta: int = 0) -> str:
    """Get month-year string with optional offset.

    Args:
        months_delta: Number of months to subtract from current date.
                     Positive values go back in time.

    Returns:
        Month-year string in 'YYYY_MM' format.

    Example:
        >>> get_month_year_string(0)
        '2024_03'
        >>> get_month_year_string(1)
        '2024_02'
    """
    current_date = datetime.now()
    # Subtract the specified number of months
    target_date = current_date - relativedelta(months=months_delta)
    formatted_date = target_date.strftime("%Y_%m")
    
    return str(formatted_date)


def get_iso_timestamp_ist() -> str:
    """Get current timestamp in ISO format with IST timezone.

    Returns:
        Current timestamp as ISO formatted string with IST offset (+05:30).

    Example:
        >>> get_iso_timestamp_ist()
        '2024-03-15T14:30:25+05:30'
    """
    # IST is UTC+5:30
    ist_offset = timezone(timedelta(hours=5, minutes=30))
    current_dt = datetime.now(ist_offset).replace(microsecond=0)
    return current_dt.isoformat()
